searchData={"content_type":"text/markdown","items":[{"doc":"Defines the connection to Supabase, it is an Agent that holds the connection\ninformation and the current bucket.\n\nTo start the connection you need to call `Supabase.Connection.start_link/1`:\n\n    iex> Supabase.Connection.start_link(name: :my_conn, conn_info: %{base_url: \"https://myapp.supabase.io\", api_key: \"my_api_key\"})\n    {:ok, #PID }\n\nBut usually you would add the connection to your supervision tree:\n\n    defmodule MyApp.Application do\n      use Application\n\n      def start(_type, _args) do\n        conn_info = %{base_url: \"https://myapp.supabase.io\", api_key: \"my_api_key\"}\n\n        children = [\n          {Supabase.Connection, conn_info: conn_info, name: :my_conn}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n    end\n\nOnce the connection is started you can use it to perform operations on the\nstorage service, for example to list all the buckets:\n\n    iex> conn = Supabase.Connection.fetch_current_bucket!(:my_conn)\n    iex> Supabase.Storage.list_buckets(conn)\n    {:ok, [\n      %Supabase.Storage.Bucket{\n        allowed_mime_types: nil,\n        file_size_limit: nil,\n        id: \"my-bucket-id\",\n        name: \"my-bucket\",\n        public: true\n      }\n    ]}\n\nNotice that you can start multiple connections, each one with different\ncredentials, and you can use them to perform operations on different buckets!","ref":"Supabase.Connection.html","title":"Supabase.Connection","type":"module"},{"doc":"Currently the connection holds the following fields:\n\n- `:base_url` - The base url of the Supabase API, it is usually in the form\n  `https:// .supabase.io`.\n- `:api_key` - The API key used to authenticate requests to the Supabase API.\n- `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `name`: Simple field to track the name of the connection, started by `start_link/1`.\n- `alias`: Field to easily manage multiple connections on a `Supabase.Client` Agent.","ref":"Supabase.Connection.html#module-fields","title":"Fields - Supabase.Connection","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supabase.Connection.html#child_spec/1","title":"Supabase.Connection.child_spec/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#fetch_current_bucket!/1","title":"Supabase.Connection.fetch_current_bucket!/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#get_access_token/1","title":"Supabase.Connection.get_access_token/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#get_api_key/1","title":"Supabase.Connection.get_api_key/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#get_base_url/1","title":"Supabase.Connection.get_base_url/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#put_access_token/2","title":"Supabase.Connection.put_access_token/2","type":"function"},{"doc":"","ref":"Supabase.Connection.html#put_current_bucket/2","title":"Supabase.Connection.put_current_bucket/2","type":"function"},{"doc":"","ref":"Supabase.Connection.html#remove_current_bucket/1","title":"Supabase.Connection.remove_current_bucket/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#retrieve_connection/1","title":"Supabase.Connection.retrieve_connection/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#start_link/1","title":"Supabase.Connection.start_link/1","type":"function"},{"doc":"","ref":"Supabase.Connection.html#t:access_token/0","title":"Supabase.Connection.access_token/0","type":"type"},{"doc":"","ref":"Supabase.Connection.html#t:api_key/0","title":"Supabase.Connection.api_key/0","type":"type"},{"doc":"","ref":"Supabase.Connection.html#t:base_url/0","title":"Supabase.Connection.base_url/0","type":"type"},{"doc":"","ref":"Supabase.Connection.html#t:bucket/0","title":"Supabase.Connection.bucket/0","type":"type"},{"doc":"","ref":"Supabase.Connection.html#t:params/0","title":"Supabase.Connection.params/0","type":"type"},{"doc":"","ref":"Supabase.Connection.html#t:t/0","title":"Supabase.Connection.t/0","type":"type"},{"doc":"A changeset for validating and parsing connection options. This is mainly\nused internally by `Supabase` module, but can be used to validate and parse\nconnection options manually.","ref":"Supabase.ConnectionOptions.html","title":"Supabase.ConnectionOptions","type":"module"},{"doc":"","ref":"Supabase.ConnectionOptions.html#parse/1","title":"Supabase.ConnectionOptions.parse/1","type":"function"},{"doc":"","ref":"Supabase.ConnectionOptions.html#to_connection_info/1","title":"Supabase.ConnectionOptions.to_connection_info/1","type":"function"},{"doc":"","ref":"Supabase.ConnectionOptions.html#t:t/0","title":"Supabase.ConnectionOptions.t/0","type":"type"},{"doc":"A supervisor for all connections. In most cases this should be started\nautomatically by the application supervisor and be used mainly by\nthe `Supabase` module, availaton on `:supabase_potion` application.\n\nAlthough if you want to manage connections manually, you can leverage\nthis module to start and stop connections dynamically. To see how to start\na single connection manually, check `Supabase.Connection` module docs.","ref":"Supabase.ConnectionSupervisor.html","title":"Supabase.ConnectionSupervisor","type":"module"},{"doc":"iex> Supabase.ConnectionSupervisor.start_link([])\n    {:ok, #PID }\n\n    iex> Supabase.ConnectionSupervisor.start_child({Supabase.Connection, opts})\n    {:ok, #PID }","ref":"Supabase.ConnectionSupervisor.html#module-examples","title":"Examples - Supabase.ConnectionSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supabase.ConnectionSupervisor.html#child_spec/1","title":"Supabase.ConnectionSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"Supabase.ConnectionSupervisor.html#start_child/1","title":"Supabase.ConnectionSupervisor.start_child/1","type":"function"},{"doc":"","ref":"Supabase.ConnectionSupervisor.html#start_link/1","title":"Supabase.ConnectionSupervisor.start_link/1","type":"function"},{"doc":"","ref":"Supabase.MissingSupabaseConfig.html","title":"Supabase.MissingSupabaseConfig","type":"exception"},{"doc":"# Supabase Connection\n\n![Supabase Logo](https://supabase.io/img/supabase-logo.svg)\n\nThe **Supabase Connection** is a fundamental component of the Supabase ecosystem, designed to streamline your interaction with the Supabase platform from your Elixir applications. This package enables you to manage connections to Supabase, allowing you to perform various operations on Supabase services such as storage, authentication, and more.","ref":"readme.html","title":"Supabase Connection","type":"extras"},{"doc":"To get started, you can add the `supabase_connection` package to your Elixir project's dependencies by including it in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:supabase_connection, \"~> 0.1\"}\n  ]\nend\n```\n\nAfter adding the dependency, run `mix deps.get` to fetch and install the SDK.","ref":"readme.html#installation","title":"Installation - Supabase Connection","type":"extras"},{"doc":"The core concept of this package is the `Supabase.Connection`, which represents your connection to Supabase. You can start a connection using the `Supabase.Connection.start_link/1` function. For example:\n\n```elixir\niex> Supabase.Connection.start_link(name: :my_conn, conn_info: %{base_url: \"https://myapp.supabase.io\", api_key: \"my_api_key\"})\n{:ok, #PID }\n```\n\nHowever, it's more common to add the connection to your supervision tree for better management. Here's an example of how to do this in your application module:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    conn_info = %{base_url: \"https://myapp.supabase.io\", api_key: \"my_api_key\"}\n\n    children = [\n      {Supabase.Connection, conn_info: conn_info, name: :my_conn}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"readme.html#starting-a-connection","title":"Starting a Connection - Supabase Connection","type":"extras"},{"doc":"Once you have started a connection, you can use it to perform various operations on Supabase services. For example, you can list all the buckets in the storage service:\n\n```elixir\niex> conn = Supabase.Connection.fetch_current_bucket!(:my_conn)\niex> Supabase.Storage.list_buckets(conn)\n{:ok, [\n  %Supabase.Storage.Bucket{\n    allowed_mime_types: nil,\n    file_size_limit: nil,\n    id: \"my-bucket-id\",\n    name: \"my-bucket\",\n    public: true\n  }\n]}\n```\n\nYou can start multiple connections, each with different credentials, to perform operations on different buckets.","ref":"readme.html#using-connections","title":"Using Connections - Supabase Connection","type":"extras"},{"doc":"A `Supabase.Connection` holds various fields, including:\n\n- `:base_url`: The base URL of the Supabase API.\n- `:api_key`: The API key used for authentication.\n- `:access_token`: A token with specific permissions.\n- `:name`: A simple field to track the name of the connection.\n- `:alias`: A field to manage multiple connections on a `Supabase.Client` Agent.","ref":"readme.html#configuration-and-fields","title":"Configuration and Fields - Supabase Connection","type":"extras"},{"doc":"This package is a critical part of the Supabase Elixir ecosystem, enabling seamless integration with Supabase services. It plays a central role in connecting your Elixir applications to the power of Supabase.","ref":"readme.html#acknowledgements","title":"Acknowledgements - Supabase Connection","type":"extras"},{"doc":"For more details on using this package and the Supabase Elixir SDK as a whole, refer to the [Supabase Elixir SDK documentation](https://hexdocs.pm/supabase_connection).\n\n---\n\nWith the **Supabase Connection Elixir SDK**, you can effortlessly manage connections to the Supabase platform, empowering your Elixir applications to leverage the full potential of Supabase's cloud services. Enjoy coding with Supabase! 😄","ref":"readme.html#additional-information","title":"Additional Information - Supabase Connection","type":"extras"}]}